@@ -1,6 +1,6 @@
 package Task::Kensho::Testing;
 use strict;
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 __END__
 
@@ -12,7 +12,7 @@ Task::Kensho::Testing - A Glimpse at an Enlightened Perl (Testing)
 
 =head1 VERSION
 
-This document describes Task::Kensho::Testing version 0.28
+This document describes Task::Kensho::Testing version 0.29
 
 =head1 SYNOPSIS
 
@@ -62,9 +62,9 @@ Basic utilities for writing tests.
 
 Most commonly needed test functions and features.
 
-=item L<Test::Exception|Test::Exception>
+=item L<Test::Fatal|Test::Fatal>
 
-Test exception based code
+Test exception-based code
 
 =item L<Test::Pod|Test::Pod>
 
@@ -82,6 +82,18 @@ Check for memory leaks and circular memory references
 
 Code coverage metrics for Perl
 
+=item L<Test::Deep|Test::Deep>
+
+Test deep data structures
+
+=item L<Test::Requires|Test::Requires>
+
+Make running a test conditional on a particular module being installed
+
+=item L<Test::NoWarnings>
+
+Ensure that no (unexpected) warnings occur during testing
+
 =back
 
 =head1 RELEASE SCHEDULE
